<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Ontario";
    var qsoPartyUrl = "http://www.va3cco.com/oqp";
    var overlayUrl = "http://www.no5w.com/OverlayON_Rev4.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Algoma", "alg");
  countySelection.options[1] = new Option("Brant", "bra");
  countySelection.options[2] = new Option("Brantford", "bfd");
  countySelection.options[3] = new Option("Bruce", "bru");
  countySelection.options[4] = new Option("ChathamKent", "chk");
  countySelection.options[5] = new Option("Cochrane", "coc");
  countySelection.options[6] = new Option("Dufferin", "duf");
  countySelection.options[7] = new Option("Durham", "dur");
  countySelection.options[8] = new Option("Elgin", "elg");
  countySelection.options[9] = new Option("Essex", "esx");
  countySelection.options[10] = new Option("Frontenac", "fro");
  countySelection.options[11] = new Option("Grey", "gry");
  countySelection.options[12] = new Option("Haldimand", "hal");
  countySelection.options[13] = new Option("Haliburton", "hlb");
  countySelection.options[14] = new Option("Halton", "htn");
  countySelection.options[15] = new Option("Hamilton", "ham");
  countySelection.options[16] = new Option("Hastings", "has");
  countySelection.options[17] = new Option("Huron", "hur");
  countySelection.options[18] = new Option("KawarthaLakes", "kaw");
  countySelection.options[19] = new Option("Kenora", "ken");
  countySelection.options[20] = new Option("Lambton", "lam");
  countySelection.options[21] = new Option("Lanark", "lan");
  countySelection.options[22] = new Option("LeedsGrenville", "lgr");
  countySelection.options[23] = new Option("LennoxAddington", "lxa");
  countySelection.options[24] = new Option("Manitoulin", "man");
  countySelection.options[25] = new Option("Middlesex", "msx");
  countySelection.options[26] = new Option("Muskoka", "mus");
  countySelection.options[27] = new Option("Niagara", "nia");
  countySelection.options[28] = new Option("Nipissing", "nip");
  countySelection.options[29] = new Option("Norfolk", "nfk");
  countySelection.options[30] = new Option("Northumberland", "nor");
  countySelection.options[31] = new Option("Ottawa", "ott");
  countySelection.options[32] = new Option("Oxford", "oxf");
  countySelection.options[33] = new Option("ParrySound", "psd");
  countySelection.options[34] = new Option("Peel", "pel");
  countySelection.options[35] = new Option("Perth", "per");
  countySelection.options[36] = new Option("Peterborough", "pet");
  countySelection.options[37] = new Option("PrescottRussell", "pru");
  countySelection.options[38] = new Option("PrinceEdward", "ped");
  countySelection.options[39] = new Option("RainyRiver", "rai");
  countySelection.options[40] = new Option("Renfrew", "ren");
  countySelection.options[41] = new Option("Simcoe", "sim");
  countySelection.options[42] = new Option("StormontDundasGlengarry", "sdg");
  countySelection.options[43] = new Option("Sudbury", "sud");
  countySelection.options[44] = new Option("ThunderBay", "tby");
  countySelection.options[45] = new Option("Timiskaming", "tim");
  countySelection.options[46] = new Option("Toronto", "tor");
  countySelection.options[47] = new Option("Waterloo", "wat");
  countySelection.options[48] = new Option("Wellington", "wel");
  countySelection.options[49] = new Option("York", "yrk");
  addMarker(47.89730000, -83.63930000, "Algoma", "alg");
  addMarker(43.13970000, -80.29640000, "Brant", "bra");
  addMarker(43.14760000, -80.27070000, "Brantford", "bfd");
  addMarker(44.58480000, -81.35250000, "Bruce", "bru");
  addMarker(42.34790000, -82.07820000, "ChathamKent", "chk");
  addMarker(50.29050000, -83.03240000, "Cochrane", "coc");
  addMarker(44.02820000, -80.19480000, "Dufferin", "duf");
  addMarker(44.15470000, -78.88190000, "Durham", "dur");
  addMarker(42.69080000, -81.27400000, "Elgin", "elg");
  addMarker(42.14990000, -82.78740000, "Essex", "esx");
  addMarker(44.66040000, -76.70360000, "Frontenac", "fro");
  addMarker(44.38640000, -80.68480000, "Grey", "gry");
  addMarker(42.95920000, -79.81030000, "Haldimand", "hal");
  addMarker(45.15750000, -78.48100000, "Haliburton", "hlb");
  addMarker(43.50550000, -79.88940000, "Halton", "htn");
  addMarker(43.26080000, -79.93600000, "Hamilton", "ham");
  addMarker(44.72770000, -77.60700000, "Hastings", "has");
  addMarker(43.64520000, -81.36320000, "Huron", "hur");
  addMarker(44.52210000, -78.81730000, "KawarthaLakes", "kaw");
  addMarker(52.93120000, -88.30910000, "Kenora", "ken");
  addMarker(42.82550000, -82.27320000, "Lambton", "lam");
  addMarker(45.05810000, -76.29680000, "Lanark", "lan");
  addMarker(44.71660000, -75.94420000, "LeedsGrenville", "lgr");
  addMarker(44.64010000, -77.08000000, "LennoxAddington", "lxa");
  addMarker(45.85870000, -82.01980000, "Manitoulin", "man");
  addMarker(42.94880000, -81.36720000, "Middlesex", "msx");
  addMarker(45.15040000, -79.46460000, "Muskoka", "mus");
  addMarker(43.04630000, -79.33000000, "Niagara", "nia");
  addMarker(46.27240000, -78.92780000, "Nipissing", "nip");
  addMarker(42.78520000, -80.39470000, "Norfolk", "nfk");
  addMarker(44.17310000, -78.07520000, "Northumberland", "nor");
  addMarker(45.25140000, -75.80020000, "Ottawa", "ott");
  addMarker(43.08860000, -80.78440000, "Oxford", "oxf");
  addMarker(45.66750000, -79.82900000, "ParrySound", "psd");
  addMarker(43.73320000, -79.84170000, "Peel", "pel");
  addMarker(43.52410000, -81.08940000, "Perth", "per");
  addMarker(44.49910000, -78.19110000, "Peterborough", "pet");
  addMarker(45.41400000, -74.90360000, "PrescottRussell", "pru");
  addMarker(44.00280000, -77.22210000, "PrinceEdward", "ped");
  addMarker(48.71180000, -92.89300000, "RainyRiver", "rai");
  addMarker(45.69590000, -77.35440000, "Renfrew", "ren");
  addMarker(44.42370000, -79.68680000, "Simcoe", "sim");
  addMarker(45.15720000, -74.97060000, "StormontDundasGlengarry", "sdg");
  addMarker(47.23270000, -82.07800000, "Sudbury", "sud");
  addMarker(49.73330000, -88.14780000, "ThunderBay", "tby");
  addMarker(47.66900000, -80.63350000, "Timiskaming", "tim");
  addMarker(43.71640000, -79.37240000, "Toronto", "tor");
  addMarker(43.47820000, -80.52830000, "Waterloo", "wat");
  addMarker(43.70670000, -80.48030000, "Wellington", "wel");
  addMarker(44.10490000, -79.46580000, "York", "yrk");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

